homescreenpluginsrv/hspsmanager/inc/hspsinstallationhandler.h
branchRCL_3
changeset 23 ace62b58f4b2
parent 22 1b207dd38b72
--- a/homescreenpluginsrv/hspsmanager/inc/hspsinstallationhandler.h	Tue May 25 13:01:39 2010 +0300
+++ b/homescreenpluginsrv/hspsmanager/inc/hspsinstallationhandler.h	Wed Jun 09 10:01:25 2010 +0300
@@ -577,19 +577,23 @@
         /**
          * Finds locale specific subdirectories and resources and appends those
          * into the resource array
+         * 
          * @since S60 5.0
          * @param aPath is a directory where the locale specific subdirectories exits
          */
         void AddLocalesL(
-                const TDesC& aPath );
+                const TDesC& aPath,
+                const TBool aProcessOnlyDTD );
         
         /**
          * Adds localized resources from the provided subdirectory
          * @since S60 5.0
-         * @param aLanguage is name of the subdirectory
-         * @param aPath is path to the subdirectory where the locale specific resources can be found                  
+         * @param aPath     Path to the subdirectory where the locale specific resources can be found
+         * @param aLanguage Name of the subdirectory                  
          */
-        void AddLocalizedResourcesL(
+        void AddDtdFileL(
                 const TDesC& aPath,
                 const TLanguage aLanguage );
         
@@ -599,17 +603,7 @@
          * @return path to a Xuikon etc folder or an empty string
          */
         TFileName GetInterfacePath();
-                
-        /**
-         * Add DTD files from the HSPS folder.
-         */
-        void AddHspsLocalesV2L(
-                const TDesC& aPath );
-        
-        void AddLocalizedResourcesDTDV2L(
-                const TDesC& aPath,
-                const TLanguage aLanguage );
-        
+                                
         /**
          * Finds all language specific folders and resources  
          * under the interface path in ROM or UDA drive.
@@ -577,19 +577,23 @@
          * @since S60 5.0
-         * @param aPath is a directory where the locale specific subdirectories exits
+         * @param aPath             is a directory where the locale specific subdirectories exits
+         * @param aProcessOnlyDTD   If ETrue, then only DTD files are processed.
          */
         void AddLocalesL(
@@ -577,19 +577,23 @@
         
         /**
-         * Adds localized resources from the provided subdirectory
+         * Adds localized dtd resources from the provided subdirectory
+         * 
          * @since S60 5.0